searchData={"items":[{"type":"task","title":"mix github_workflows.generate","doc":"Generates GitHub Actions YAML workflow files.\n\n    $ mix github_workflows.generate [--dir .github/workflows] [--source .github/github_workflows.ex]\n\nWorkflows will be read from the `source` file and stored in the `dir` directory.","ref":"Mix.Tasks.GithubWorkflows.Generate.html"},{"type":"task","title":"Options - mix github_workflows.generate","doc":"* `--dir` - directory path to store the generated workflows. Defaults to `.github/workflows`.\n  * `--source` - path to the source file containing the map of workflows. Defaults to `.github/github_workflows.ex`.","ref":"Mix.Tasks.GithubWorkflows.Generate.html#module-options"},{"type":"task","title":"Example - mix github_workflows.generate","doc":"Given the following `.github/github_workflows.ex` file:\n\n```elixir\ndefmodule GithubWorkflows do\n  def get do\n    %{\n      \"main.yml\" => main_workflow(),\n      \"pr.yml\" => pr_workflow()\n    }\n  end\n\n  defp main_workflow do\n    [\n      [\n        name: \"Main\",\n        on: [\n          push: [\n            branches: [\"main\"]\n          ]\n        ],\n        jobs: [\n          test: test_job(),\n          deploy: [\n            name: \"Deploy\",\n            needs: :test,\n            steps: [\n              checkout_step(),\n              [\n                name: \"Deploy\",\n                run: \"make deploy\"\n              ]\n            ]\n          ]\n        ]\n      ]\n    ]\n  end\n\n  defp pr_workflow do\n    [\n      [\n        name: \"PR\",\n        on: [\n          pull_request: [\n            branches: [\"main\"]\n          ]\n        ],\n        jobs: [\n          test: test_job()\n        ]\n      ]\n    ]\n  end\n\n  defp test_job do\n    [\n      name: \"Test\",\n      steps: [\n        checkout_step(),\n        [\n          name: \"Run tests\",\n          run: \"make test\"\n        ]\n      ]\n    ]\n  end\n\n  defp checkout_step do\n    [\n      name: \"Checkout\",\n      uses: \"actions/checkout@v4\"\n    ]\n  end\nend\n```\n\nrunning the `mix github_workflows.generate` task will output the following files:\n\n`.github/workflows/main.yml`:\n\n```yaml\nname: Main\non:\n  push:\n    branches:\n      - main\njobs:\n  test:\n    name: Test\n    steps:\n      - name: Checkout\n        uses: actions/checkout@v4\n      - name: Run tests\n        run: make test\n  deploy:\n    name: Deploy\n    needs: test\n    steps:\n      - name: Checkout\n        uses: actions/checkout@v4\n      - name: Deploy\n        run: make deploy\n```\n\n`.github/workflows/pr.yml`:\n\n```yaml\nname: PR\non:\n  pull_request:\n    branches:\n      - main\njobs:\n  test:\n    name: Test\n    steps:\n      - name: Checkout\n        uses: actions/checkout@v4\n      - name: Run tests\n        run: make test\n```\n\nMore complex workflows can be found here:\nhttps://github.com/optimumBA/github_workflows_generator/blob/main/.github/github_workflows.ex","ref":"Mix.Tasks.GithubWorkflows.Generate.html#module-example"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}